Yandex 360 Lib
==============

Библиотека функций для работы с Yandex 360 API

.. code-block:: console

  pip install yandex_360

Документация
------------

`yandex_360 <https://yandex-360.readthedocs.io/>`_
